controller

package
v0.0.0-...-21d728a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 16, 2024 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

const (
	// TODO: move this to config?
	// Port is the port that the server should listen to
	Port = 8080
)

Variables

This section is empty.

Functions

func BlackHole

func BlackHole(c *fiber.Ctx) error

func CreateRouter

func CreateRouter() *fiber.App

CreateRouter creates the router for the http server

func Handle

func Handle(loadedCfg *config.Config)

Handle creates the router and the server before starting the server

func MetaHandler

func MetaHandler(c *fiber.Ctx) error

Test endpoint

Types

type FiberFunc

type FiberFunc = func(c *fiber.Ctx) error

type Meta

type Meta struct {
	CommitHash string    `json:"commitHash"`
	BuildDate  string    `json:"buildDate"`
	SystemTime time.Time `json:"systemTime"`
}

Meta holds project metadata

Jump to